@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: common.c,v 1.60 2006/05/12 21:20:49 evertonm Exp $ */
+/* $Id: common.c,v 1.62 2006/05/19 14:19:29 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -45,7 +45,7 @@ const char * const NEPIM_LABEL_TOTAL_BROKEN = "avg(broken)";
 
 const char *nepim_version()
 {
-  return "0.25";
+  return "0.26";
 }
 
 static void nepim_dump_stat(FILE *out, struct timeval now, const char *label,
@@ -203,9 +203,6 @@ void report_broken_slot_stat(FILE *out, nepim_slot_t *slot)
   report_broken_slot_stat_at(out, slot, now);
 }
 
-#define NEPIM_MEGA (1000000)
-#define NEPIM_8MEGA (8000000)
-
 void nepim_timer_usec_add(struct timeval *tv, susec_t usec)
 {
   tv->tv_usec += usec;
@@ -249,8 +246,8 @@ int nepim_pps2packets(int pps_pkt_rate, susec_t usec_delay)
   pkts *= usec_delay;
   pkts /= NEPIM_MEGA;
 
-  assert(pkts > -2000000000);
-  assert(pkts < 2000000000);
+  assert(pkts > -NEPIM_2MEGA);
+  assert(pkts < NEPIM_2MEGA);
 
   return pkts;
 }
