@@ -21,7 +21,7 @@ MA 02110-1301 USA
 /*
   nepim - network pipemeter
 
-  $Id: main.c,v 1.52 2006/05/16 12:28:04 evertonm Exp $
+  $Id: main.c,v 1.54 2006/05/19 14:19:29 evertonm Exp $
  */
 
 #include <stdlib.h>
@@ -103,7 +103,7 @@ static void usage(FILE *out, const char *prog_name)
           "  -4             disable IPv4\n"
 	  "  -q             quietly hide soft read/write errors\n"
 	  "  -y tos         ip tos (defaults to %d, tos=-1 means don't change)\n"
-	  "  -K udp-ka-time UDP keepalive timeout in ms (defaults to %ld ms)\n"
+	  "  -K udp-ka-time UDP keepalive timeout (defaults to %ld us)\n"
 	  "\n"
           "client-only options:\n"
           "  -u             UDP mode (defaults to TCP)\n"
@@ -119,8 +119,13 @@ static void usage(FILE *out, const char *prog_name)
           "  -n pipes       number of parallel pipes (defaults to %d)\n"
           "  -r bit-rate    upper bit rate limit (defaults to %s bps)\n"
           "  -R pkt-rate    upper packet rate limit (defaults to %s pps)\n"
-	  "  -D send-delay  delay between sends (defaults to %ld ms)\n"
-	  "                 only meaningful when specified before -r or -R\n"
+	  "  -D send-delay  delay between sends (defaults to %ld us)\n"
+	  "                 only meaningful if specified before -r or -R\n"
+	  "  -e send-rate   even send rate (defaults to off)\n"
+	  "                 try to keep uniform delay between sends\n"
+	  "                 incompatible with both -R and -D\n"
+	  "                 may be disrupted by -r\n"
+	  "                 may cause higher processing loads\n"
           "  -i interval    statistics report interval (defaults to %d seconds)\n"
           "  -a age         test duration (defaults to %d seconds)\n"
           "  -S seed        starting seed (in hex) (defaults to random)\n"
@@ -598,6 +603,33 @@ int main(int argc, const char *argv[])
       continue;
     }
 
+    if (!strcmp(arg, "-e")) {
+      ++i;
+      if (i >= argc) {
+        fprintf(stderr, "%s: missing send-rate\n",
+                nepim_global.prog_name);
+        exit(1);
+      }
+      nepim_global.pkt_rate = atoi(argv[i]);
+
+      if (nepim_global.pkt_rate < 1) {
+        fprintf(stderr, "%s: excessively low send-rate: %d pps (min: 1 pps)\n",
+                nepim_global.prog_name, nepim_global.pkt_rate);
+	exit(1);
+      }
+
+      if (nepim_global.pkt_rate > NEPIM_MEGA) {
+        fprintf(stderr, "%s: excessively high send-rate: %d pps (max: %d pps)\n",
+                nepim_global.prog_name, nepim_global.pkt_rate, NEPIM_MEGA);
+	exit(1);
+      }
+
+      nepim_global.write_delay = NEPIM_MEGA / nepim_global.pkt_rate;
+
+      assert(nepim_global.pkt_rate >= nepim_min_pps(nepim_global.write_delay));
+      continue;
+    }
+
     if (!strcmp(arg, "-s")) {
       nepim_global.simplex_client_send = 1;
       continue;
@@ -757,6 +789,11 @@ int main(int argc, const char *argv[])
 
   nepim_server_run();
 
+#if 0
+  /* requires previous fd de-registration */
+  oop_sys_delete(nepim_global.oop_sys);
+#endif
+
   fprintf(stderr, "%s: done\n", nepim_global.prog_name);
   exit(0);
 }
